@@ -1,4 +1,3 @@
-/*	$Id: client.h,v 1.12 2001/09/03 00:55:40 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -18,24 +17,21 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
-/**
- * @file client.h
- * Includes generales para el cliente del TEG
+/*
+ * general includes for the TEG client
  */
 
 #ifndef __TEGC_CLIENT_H
 #define __TEGC_CLIENT_H
 
-#include "all.h"
-#include "jugador.h"
+#include "player.h"
 #include "globals.h"
 #include "misc.h"
-#include "aux.h"
+#include "helper.h"
 #include "inputfd.h"
 #include "outputfd.h"
-#include "paises.h"
 #include "fichas.h"
-#include "ataque.h"
+#include "attack.h"
 #include "reagrupe.h"
 #include "ejer2.h"
 #include "canje.h"
