@@ -1,4 +1,3 @@
-/*	$Id: ejer2.h,v 1.3 2001/09/03 00:55:40 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -18,14 +17,39 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
-/**
- * @file ejer2.h
+
+#pragma once
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+
+/** \brief Try to get two armies for one country.
+ *
+ * This function tries to request two armies for the \p country. This works when
+ * the country belongs to the player, and nobody before got a card for this
+ * country.
+ *
+ * \todo Change the return type to bool.
+ *
+ * \return TEG_STATUS_SUCCESS if the function sent the request to the
+ *         game controller, TEG_STATUS_ERROR otherwise.
  */
+TEG_STATUS ejer2_out(int country);
 
-#ifndef __TEGC_EJER2_H
-#define __TEGC_EJER2_H
-
-TEG_STATUS ejer2_out( int pais );
+/** \brief Undo a previous army exchange.
+ *
+ * This is called when the game controller decided that the exchange of armies
+ * is not possible. It rools back the previous ejer2_out call.
+ *
+ * \todo Change the return type to bool.
+ *
+ * \return TEG_STATUS_SUCCESS if there was an active ejer2_out call,
+ *         TEG_STATUS_ERROR otherwise.
+ */
 TEG_STATUS ejer2_restore_from_error();
 
-#endif /* __TEGC_EJER2_H */
+#ifdef __cplusplus
+}
+#endif
