@@ -1,4 +1,3 @@
-/*	$Id: armies.h,v 1.7 2001/09/03 00:55:40 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -27,13 +26,13 @@
 typedef struct _armies_pos {
 	int cant;
 	int orig_cant;
-	GnomeCanvasItem *armies_text;
+	GooCanvasItem *armies_text;
 } ARMIES_POS, *PARMIES_POS;
 
-TEG_STATUS armies_add(int pais);
-TEG_STATUS armies_del(int pais);
+TEG_STATUS armies_add(int country);
+TEG_STATUS armies_del(int country);
 TEG_STATUS armies_view(int cant, int conts);
-TEG_STATUS armies_view_more( int cant );
+TEG_STATUS armies_view_more(int cant);
 TEG_STATUS armies_unview();
 TEG_STATUS armies_init();
 
