@@ -1,5 +1,4 @@
-/*	$Id: chatline.h,v 1.2 2001/05/01 18:28:51 riq Exp $	*/
-/********************************************************************** 
+/**********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,9 +16,10 @@
 #ifndef __TEG_GUI_GNOME_CHATLINE_H
 #define __TEG_GUI_GNOME_CHATLINE_H
 
-void inputline_return(GtkWidget *w, gpointer data);
+void inputline_return(GtkEntry *w, gpointer data);
 void output_window_clear(void);
+void set_output_window_text(const char *text);
 TEG_STATUS gui_textmsg(char *astring);
-TEG_STATUS gui_textplayermsg(char *name, int nj, char *msg);
+TEG_STATUS chatline_init();
 
 #endif  /* __TEG_GUI_GNOME_CHATLINE_H */
