@@ -1,4 +1,3 @@
-/*	$Id: colors.h,v 1.11 2002/09/21 17:56:38 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -48,23 +47,20 @@ struct _G_colores {
 	char *text_color;
 };
 extern struct _G_colores G_colores[];
-extern GdkPixbuf	*g_soldier[];
+extern GdkPixbuf	*g_color_players[];
 extern GdkPixbuf	*g_color_circles[];
 extern GdkPixbuf	*g_color_circle_over;
-extern GdkGC *g_colors_gc;
-extern GdkFont* g_pixmap_font10;
 
-TEG_STATUS colors_allocate( void );
-TEG_STATUS colors_free();
-TEG_STATUS colors_load_images( void );
-GdkColor* colors_get_player( int n );
-GdkColor* colors_get_player_from_color( int color );
-GdkColor* colors_get_player_ink(int n );
-GdkColor* colors_get_player_ink_from_color(int color );
-GdkColor* colors_get_player_virtual( int n );
-GdkColor* colors_get_common( int n );
-char * get_tag_for_color( int color );
-char * get_background_for_color( int c );
-char * get_foreground_for_color( int c );
+TEG_STATUS colors_allocate(void);
+TEG_STATUS colors_load_images(void);
+GdkRGBA* colors_get_player(int n);
+GdkRGBA* colors_get_player_from_color(int color);
+GdkRGBA* colors_get_player_ink(int n);
+GdkRGBA* colors_get_player_ink_from_color(int color);
+GdkRGBA* colors_get_player_virtual(int n);
+GdkRGBA* colors_get_common(int n);
+char * get_tag_for_color(int color);
+char * get_background_for_color(int c);
+char * get_foreground_for_color(int c);
 
 #endif /* __TEG_GUI_GNOME_COLORS_H */
