@@ -1,4 +1,3 @@
-/*	$Id: connect.h,v 1.1 2002/09/02 03:20:10 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -18,14 +17,34 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
+
+#pragma once
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+enum DisconnectReason {
+	/// the client decided to terminate the connection (for example with the
+	/// disconnect button
+	DR_NORMAL_DISCONNECT,
+
+	/// There was an unrecoverable IO error
+	DR_IO_ERROR,
+};
+
 /**
- * @file connect.h
+ * Shut down the connection to the server, reset the GUI and print a message
+ * about the disconnect.
+ *
+ * \param reason Why was the connectio shut down?
  */
-#ifndef __GUI_GNOME_CONECTAR_H
-#define __GUI_GNOME_CONECTAR_H
+void disconnect(enum DisconnectReason reason);
 
 void connect_view();
 void gametype_view();
-void colortype_view( char *colores);
+void colortype_view(char *colores);
 
-#endif /* __GUI_GNOME_CONECTAR_H */
+#ifdef __cplusplus
+}
+#endif
