@@ -1,4 +1,3 @@
-/*	$Id: dices.h,v 1.5 2001/09/03 00:55:40 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -26,6 +25,6 @@
 
 void dices_view();
 void dices_unview();
-void dices_init( GnomeCanvasGroup *root);
+void dices_init(GooCanvasItem *root);
 
-#endif 
+#endif
