@@ -1,4 +1,3 @@
-/*	$Id: g_scores.h,v 1.2 2001/12/21 22:10:01 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -19,15 +18,15 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 /**
- * @file status.h
+ * @file g_scores.h
  */
-#ifndef __GUI_GNOME_STATUS_H
-#define __GUI_GNOME_STATUS_H
+#ifndef __GUI_GNOME_SCORES_H
+#define __GUI_GNOME_SCORES_H
 
 /**! view the hiscores */
 void gui_scores_view();
 
 /**! place the scores insice an hbox */
-void gui_scores_embed( GtkWidget *hbox );
+void gui_scores_embed(GtkWidget *hbox);
 
-#endif /* __GUI_GNOME_STATUS_H */
+#endif /* __GUI_GNOME_SCORES_H */
