@@ -1,4 +1,3 @@
-/*	$Id: priv.c,v 1.5 2001/09/03 00:55:40 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -22,7 +21,7 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
-#include <gnome.h>
+#include <gtk/gtk.h>
 
 #include "gui.h"
 #include "client.h"
@@ -32,10 +31,14 @@
 
 struct _gui_private gui_private;
 
-TEG_STATUS priv_init( void )
+/* Prefs */
+GSettings *settings = NULL;
+
+TEG_STATUS priv_init(void)
 {
-	gui_private.tag = -1;
-	gui_private.msg_show_colors = 0;
+	gui_private.msg_show_colors
+	    = g_settings_get_boolean(settings, "msgshow-with-color");
+	gui_private.country_i_am = -1;
 
 	return TEG_STATUS_SUCCESS;
 }
