@@ -1,4 +1,3 @@
-/*	$Id: priv.h,v 1.11 2002/10/13 23:29:08 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -22,8 +21,7 @@
 #ifndef __TEG_GUI_GNOME_PRIV_H
 #define __TEG_GUI_GNOME_PRIV_H
 
-#include <gnome.h>
-#include <gconf/gconf-client.h>
+#include <gtk/gtk.h>
 
 enum {
 	DIALOG_ATTACK_TURN,
@@ -32,8 +30,6 @@ enum {
 };
 
 struct _gui_private {
-	int tag;
-	int tag_ggz;
 	BOOLEAN msg_show_colors;
 	unsigned int status_show;	/* what columns to show in the status window */
 	unsigned int dialog_show;	/* what dialogs to show */
@@ -42,8 +38,8 @@ struct _gui_private {
 
 extern struct _gui_private gui_private;
 
-extern GConfClient *g_conf_client;
+extern GSettings *settings;
 
-TEG_STATUS priv_init( void );
+TEG_STATUS priv_init(void);
 
 #endif /* __TEG_GUI_GNOME_PRIV_H */
