@@ -1,4 +1,3 @@
-/*	$Id: support.h,v 1.19 2001/12/21 16:55:53 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -22,11 +21,11 @@
 #ifndef __TEG_GUI_GNOME_SUPPORT_H
 #define __TEG_GUI_GNOME_SUPPORT_H
 
-void generic_window_set_parent (GtkWidget * dialog, GtkWindow   * parent);
-char * load_pixmap_file( char *name );
-void teg_dialog( char* title, char* bigtitle, char* data );
-GtkWidget* teg_dialog_new( char* title, char* bigtitle );
-void dialog_close( GtkWidget *button, gpointer data );
-GtkWidget * teg_dialog_gameover( int numjug, int mission );
+void generic_window_set_parent(GtkWidget * dialog, GtkWindow   * parent);
+char * load_pixmap_file(char *name);
+void teg_dialog(char* title, char* bigtitle, char* data);
+GtkWidget* teg_dialog_new(char* title, char* bigtitle);
+void teg_dialog_gameover(int numjug, int mission);
+gchar *translate_to_utf8(const gchar *string);
 
 #endif /* __TEG_GUI_GNOME_SUPPORT_H */
