@@ -1,4 +1,3 @@
-/*	$Id: main.c,v 1.25 2002/09/07 19:25:56 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -25,6 +24,7 @@
 
 #include <stdio.h>
 
+#include "../common/share.h"
 #include "client.h"
 
 TEG_STATUS main_init()
@@ -33,21 +33,16 @@ TEG_STATUS main_init()
 	g_game.human = 1;
 	player_init();
 	scores_init();
-	metaserver_init();
 	return TEG_STATUS_SUCCESS;
 }
 
-int main( int argc, char **argv)
+int main(int argc, char **argv)
 {
-	int i;
-
 	dont_run_as_root();
 
-	i = 1;
-
 	main_init();
 
-	if( gui_init(argc, argv) != TEG_STATUS_SUCCESS ) {
+	if(gui_init(argc, argv) != TEG_STATUS_SUCCESS) {
 		printf("Aborting...\n");
 		exit(-1);
 	}
