@@ -1,4 +1,3 @@
-/*	$Id: misc.c,v 1.65 2002/10/13 23:29:08 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -28,26 +27,30 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <dirent.h>
+#include <string.h>
 
 #include <glib.h>
 
-#include "ggz_client.h"
-
+#include "../common/net.h"
+#include "protocol.h"
+#include "fcintl.h"
 #include "client.h"
 
 CJUEGO g_game;			/**< client game */
 
-static void close_descriptors( void )
+static void close_descriptors(void)
 {
 	int i, open_max;
 
 	/* force manually the close of the socket */
-	if( g_game.fd >0 )
-		net_close (g_game.fd);
+	if(g_game.fd >0) {
+		net_close(g_game.fd);
+	}
 
-	open_max = sysconf (_SC_OPEN_MAX);
-	for (i = 3; i < open_max; i++)
-		fcntl (i, F_SETFD, FD_CLOEXEC);
+	open_max = sysconf(_SC_OPEN_MAX);
+	for(i = 3; i < open_max; i++) {
+		fcntl(i, F_SETFD, FD_CLOEXEC);
+	}
 }
 
 /* re-initializes a game. called every time a new game will start */
@@ -58,18 +61,18 @@ TEG_STATUS game_reinit()
 	g_game.playeres = 0;
 	g_game.dados_srccountry=-1;
 	g_game.dados_dstcountry=-1;
-	for(i=0;i<3;i++) {
+	for(i=0; i<3; i++) {
 		g_game.dados_src[i] = 0;
 		g_game.dados_dst[i] = 0;
 	}
 
-	InitializeListHead( &g_game.tarjetas_list );
+	InitializeListHead(&g_game.tarjetas_list);
 	g_game.tarjetas_cant = 0;
-	for(i=0;i<COUNTRIES_CANT;i++)
-		tarjeta_inittarj( &g_countries[i].tarjeta );
+	for(i=0; i<COUNTRIES_CANT; i++) {
+		tarjeta_inittarj(&g_countries[i].tarjeta);
+	}
 
 	g_game.secret_mission = -1;
-	g_game.rules = TEG_RULES_TEG;
 	g_game.whos_turn = -1;
 	g_game.who_started_round = -1;
 	g_game.round_number = -1;
@@ -82,7 +85,7 @@ TEG_STATUS game_reinit()
 
 
 /* initializes a game */
-TEG_STATUS game_init()
+void game_init()
 {
 	static int firsttime=1;
 	g_game.fd = -1;
@@ -92,7 +95,6 @@ TEG_STATUS game_init()
 	/* variables seteadas por command line y que pueden cambiar estos defaults */
 	if(firsttime) {
 		dirs_create();
-		g_game.with_ggz = 0;
 		g_game.already_connected = 0;
 	}
 
@@ -103,70 +105,44 @@ TEG_STATUS game_init()
 	/* name, server, serverport, color is assigned in the gui */
 
 	firsttime=0;
-
-	return TEG_STATUS_SUCCESS;
 }
 
-/* called when a game is over. initializes the client for a new game */
-TEG_STATUS game_finalize()
+void game_finalize()
 {
 	countries_init();
 	game_reinit();
-
-	return TEG_STATUS_SUCCESS;
 }
 
-/* connect to a server */
 TEG_STATUS teg_connect()
 {
-	if( ESTADO_ES(PLAYER_STATUS_DESCONECTADO)) {
+	if(ESTADO_ES(PLAYER_STATUS_DESCONECTADO)) {
 
 		/* standar mode */
-		if( !g_game.with_ggz && ! g_game.already_connected ) {
-			g_game.fd = net_connect_tcp( (char*) &g_game.sername, g_game.serport );
-			if( g_game.fd < 0) {
-				textmsg(M_ERR,_("Error while trying to connect to server '%s' at port %d"),g_game.sername,g_game.serport);
+		if(! g_game.already_connected) {
+			g_game.fd = net_connect_tcp((char*) &g_game.sername, g_game.serport);
+			if(g_game.fd < 0) {
+				textmsg(M_ERR, _("Error while trying to connect to server '%s' at port %d"), g_game.sername, g_game.serport);
 				return TEG_STATUS_ERROR;
 			}
-
-		} else if( g_game.with_ggz ) {
-
-#ifdef WITH_GGZ
-			/* GGZ mode */
-			g_game.fd = ggz_client_connect();
-			if( g_game.fd < 0 ) {
-				textmsg(M_ERR,_("Error while trying to connect to GGZ client"));
-				return TEG_STATUS_ERROR;
-			}
-#endif /* WITH_GGZ */
-		} else if( g_game.already_connected )
+		} else if(g_game.already_connected) {
 			g_game.fd = 3;
-
-		if( ! g_game.with_ggz ) {
-			out_pversion();
 		}
 
 		return TEG_STATUS_SUCCESS;
 	} else {
-		textmsg(M_ERR,_("Error, you are already connected"));
+		textmsg(M_ERR, _("Error, you are already connected"));
 		return TEG_STATUS_ERROR;
 	}
 }
 
-/* disconnects from the server */
-TEG_STATUS teg_disconnect()
+void teg_disconnect()
 {
 	ESTADO_SET(PLAYER_STATUS_DESCONECTADO);
 
 	player_flush();
 
-	if( g_game.fd > 0 ) {
-#if WITH_GGZ
-		if( g_game.with_ggz )
-			ggz_client_disconnect();
-		else
-#endif /* WITH_GGZ */
-			net_close( g_game.fd );
+	if(g_game.fd > 0) {
+		net_close(g_game.fd);
 		g_game.fd = -1;
 	}
 
@@ -174,60 +150,56 @@ TEG_STATUS teg_disconnect()
 	game_init();
 
 	gui_disconnect();
-
-
-	return TEG_STATUS_SUCCESS;
 }
 
-/* playerid_restore_from_error( void ) */
-TEG_STATUS playerid_restore_from_error( void )
+TEG_STATUS playerid_restore_from_error(void)
 {
-	textmsg( M_ERR, _("The game has already started. Connect as an observer."));
+	textmsg(M_ERR, _("The game has already started. Connect as an observer."));
 	teg_disconnect();
 	return TEG_STATUS_SUCCESS;
 }
 
 /* Launch a server in localost */
-TEG_STATUS launch_server( int port )
+TEG_STATUS launch_server(int port)
 {
 	pid_t pid;
 	char *args[6];
 
-	if ( (pid = fork()) < 0) {
+	if((pid = fork()) < 0) {
 		perror("tegclient:");
 		return TEG_STATUS_ERROR;
-	} else if (pid == 0) {
+	} else if(pid == 0) {
 
 		char buffer[100];
 		close_descriptors();
-		args[0] = "xterm";
+		args[0] = "x-terminal-emulator";
 		args[1] = "-e";
 		args[2] = BINDIR"/tegserver";
 		args[3] = "--port";
-		snprintf(buffer, sizeof(buffer)-1, "%d", port); 
+		snprintf(buffer, sizeof(buffer)-1, "%d", port);
 		buffer[ sizeof(buffer)-1 ] = 0;
 		args[4] = buffer;
 		args[5] = NULL;
 
-		if( execvp(args[0], args) < 0) {
+		if(execvp(args[0], args) < 0) {
 			perror(args[0]);
 			/* last chance, launch tegserver without console */
 			args[0] = BINDIR"/tegserver";
 			args[1] = "--console";
 			args[2] = "0";
 			args[3] = "--port";
-			snprintf(buffer, sizeof(buffer)-1, "%d", port); 
+			snprintf(buffer, sizeof(buffer)-1, "%d", port);
 			buffer[ sizeof(buffer)-1 ] = 0;
 			args[4] = buffer;
 			args[5] = NULL;
-			if( execv(args[0], args) < 0) {
-				fprintf(stderr,"Launching server failed. Does the file '%s' exists ?\n",args[0]);
+			if(execv(args[0], args) < 0) {
+				fprintf(stderr, "Launching server failed. Does the file '%s' exists ?\n", args[0]);
 				perror("exe:");
 
 				/* This saves a crash */
 				args[0] = "/bin/true";
 				args[1] = NULL;
-				execv(args[0],args);
+				execv(args[0], args);
 				exit(1);
 			}
 		}
@@ -240,25 +212,26 @@ TEG_STATUS launch_server( int port )
 }
 
 /* Launch robot in localhost */
-TEG_STATUS launch_robot( void )
+TEG_STATUS launch_robot(void)
 {
 	pid_t pid;
 	char *args[7];
 	char port[50];
 
 	/* launch robot in the server */
-	if( g_game.robot_in_server )
+	if(g_game.robot_in_server) {
 		return out_robot();
+	}
 
 	/* launch robot in the client */
-	if ( (pid = fork()) < 0) {
+	if((pid = fork()) < 0) {
 		perror("tegclient:");
 		return TEG_STATUS_ERROR;
-	} else if (pid == 0) {
+	} else if(pid == 0) {
 
 		close_descriptors();
 
-		sprintf(port,"%d",g_game.serport);
+		sprintf(port, "%d", g_game.serport);
 
 		args[0] = BINDIR"/tegrobot";
 		args[1] = "--server";
@@ -267,15 +240,15 @@ TEG_STATUS launch_robot( void )
 		args[4] = port;
 		args[5] = "--quiet";
 		args[6] = NULL;
-	
-		if( execv(args[0], args) < 0) {
-			fprintf(stderr,"Launching robot failed. Does the file '%s' exists ?\n",args[0]);
+
+		if(execv(args[0], args) < 0) {
+			fprintf(stderr, "Launching robot failed. Does the file '%s' exists ?\n", args[0]);
 			perror("exe:");
 
 			/* This saves a crash */
 			args[0] = "/bin/true";
 			args[1] = NULL;
-			execv(args[0],args);
+			execv(args[0], args);
 			exit(1);
 		}
 		return TEG_STATUS_ERROR;
@@ -286,9 +259,9 @@ TEG_STATUS launch_robot( void )
 }
 
 /* display a message */
-TEG_STATUS textmsg( int level, char *format, ...)
+TEG_STATUS textmsg(int level, char *format, ...)
 {
-        va_list args;
+	va_list args;
 	char buf[PROT_MAX_LEN];
 
 	va_start(args, format);
@@ -297,8 +270,9 @@ TEG_STATUS textmsg( int level, char *format, ...)
 
 	buf[ sizeof(buf) -1 ] = 0;
 
-	if( g_game.msg_show & level )
+	if(g_game.msg_show & level) {
 		gui_textmsg(buf);
+	}
 	return TEG_STATUS_SUCCESS;
 }
 
@@ -308,20 +282,22 @@ TEG_STATUS dirs_create()
 	DIR *dir;
 	char buf[1000];
 
-	memset(buf,0,sizeof(buf));
+	memset(buf, 0, sizeof(buf));
 
-	snprintf(buf,sizeof(buf)-1,"%s/%s",g_get_home_dir(),TEG_DIRRC);
+	snprintf(buf, sizeof(buf)-1, "%s/%s", g_get_home_dir(), TEG_DIRRC);
 
-	if( (dir = opendir(buf)) == NULL )
-		mkdir(buf,0755);
-	else
+	if((dir = opendir(buf)) == NULL) {
+		mkdir(buf, 0755);
+	} else {
 		closedir(dir);
+	}
 
-	snprintf(buf,sizeof(buf)-1,"%s/%s/themes",g_get_home_dir(),TEG_DIRRC);
-	if( (dir = opendir(buf)) == NULL )
-		mkdir(buf,0755);
-	else
+	snprintf(buf, sizeof(buf)-1, "%s/%s/themes", g_get_home_dir(), TEG_DIRRC);
+	if((dir = opendir(buf)) == NULL) {
+		mkdir(buf, 0755);
+	} else {
 		closedir(dir);
+	}
 
 	return TEG_STATUS_SUCCESS;
 }
