@@ -1,4 +1,3 @@
-/*	$Id: reagrupe.c,v 1.17 2002/09/09 03:52:06 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -23,7 +22,11 @@
  * Contiene algunas funciones auxiliares para el manejo del estado 'ESTADO_REAGRUPE'
  */
 
+#include "../common/net.h"
+
+#include "fcintl.h"
 #include "client.h"
+#include "protocol.h"
 
 static int country_origen = -1;
 static int country_destino = -1;
@@ -33,66 +36,67 @@ static int last_origen = -1;
 static int last_destino = -1;
 static int last_cant = -1;
 
-TEG_STATUS reagrupe_check( void )
+TEG_STATUS reagrupe_check(void)
 {
 	PLAYER_STATUS e = ESTADO_GET();
 
-	if( e>=PLAYER_STATUS_ATAQUE && e<=PLAYER_STATUS_REAGRUPE ) {
+	if(e>=PLAYER_STATUS_ATAQUE && e<=PLAYER_STATUS_REAGRUPE) {
 		ESTADO_SET(PLAYER_STATUS_REAGRUPE);
 		return TEG_STATUS_SUCCESS;
-	} else
+	} else {
 		return TEG_STATUS_ERROR;
+	}
 }
 
-TEG_STATUS reagrupe_click( PCOUNTRY p )
+TEG_STATUS reagrupe_click(PCOUNTRY p)
 {
-	if( reagrupe_check() != TEG_STATUS_SUCCESS ) {
-		textmsg(M_ERR,_("Error, It's not the time to regroup"));
+	if(reagrupe_check() != TEG_STATUS_SUCCESS) {
+		textmsg(M_ERR, _("Error, It's not the time to regroup"));
 		return TEG_STATUS_UNEXPECTED;
 	}
 
-	if( country_origen == -1 ) {
-		if(p->numjug == WHOAMI() ) {
-			if( p->ejercitos - p->ejer_reagrupe > 1 ) {
+	if(country_origen == -1) {
+		if(p->numjug == WHOAMI()) {
+			if(p->ejercitos - p->ejer_reagrupe > 1) {
 				p->selected &= ~COUNTRY_SELECT_REGROUP_ENTER;
 				p->selected |= COUNTRY_SELECT_REGROUP;
 				gui_country_select(p->id);
 				country_origen = p->id;
-				textmsg(M_INF,_("Source country: '%s'. Now select the destination country"),p->name);
+				textmsg(M_INF, _("Source country: '%s'. Now select the destination country"), countries_get_name(p->id));
 			} else {
-				textmsg(M_ERR,_("Error, '%s' doesnt have any avalaible armies to move"),p->name);
+				textmsg(M_ERR, _("Error, '%s' doesnt have any avalaible armies to move"), countries_get_name(p->id));
 				return TEG_STATUS_UNEXPECTED;
 			}
-		} else { 
-			textmsg(M_ERR,_("Error, '%s' isnt one of your countries"),p->name);
+		} else {
+			textmsg(M_ERR, _("Error, '%s' isnt one of your countries"), countries_get_name(p->id));
 			return TEG_STATUS_UNEXPECTED;
 		}
-	} else if( country_destino == -1 ) {
-		if( country_origen == p->id ) {
-			textmsg(M_INF,_("Source country is the same as the destination. Resetting the regroup..."));
+	} else if(country_destino == -1) {
+		if(country_origen == p->id) {
+			textmsg(M_INF, _("Source country is the same as the destination. Resetting the regroup..."));
 			reagrupe_reset();
 			return TEG_STATUS_SUCCESS;
 		}
 
-		if(p->numjug == WHOAMI()  ) {
-			if( countries_eslimitrofe( country_origen, p->id ) ) {
+		if(p->numjug == WHOAMI()) {
+			if(countries_eslimitrofe(country_origen, p->id)) {
 				p->selected &= ~COUNTRY_SELECT_REGROUP_ENTER;
 				p->selected |= COUNTRY_SELECT_REGROUP;
 				gui_country_select(p->id);
 				country_destino = p->id;
-				textmsg(M_INF,_("Destination country: '%s'. Now select the quantity of armies to move"),p->name);
+				textmsg(M_INF, _("Destination country: '%s'. Now select the quantity of armies to move"), countries_get_name(p->id));
 				gui_reagrupe(country_origen, country_destino, g_countries[country_origen].ejercitos - g_countries[country_origen].ejer_reagrupe - 1);
 			} else {
-				textmsg(M_ERR,_("Error, '%s' isnt frontier with '%s'"),p->name,g_countries[country_origen].name);
+				textmsg(M_ERR, _("Error, '%s' isnt frontier with '%s'"), countries_get_name(p->id), countries_get_name(country_origen));
 				return TEG_STATUS_UNEXPECTED;
 			}
 		} else {
-			textmsg(M_ERR,_("Error, '%s' isnt one of your countries"),p->name);
+			textmsg(M_ERR, _("Error, '%s' isnt one of your countries"), countries_get_name(p->id));
 			reagrupe_reset();
 			return TEG_STATUS_UNEXPECTED;
 		}
 	} else {
-		textmsg(M_ERR,_("Error, unexpected error in reagrupe_click(). Report this bug!"));
+		textmsg(M_ERR, _("Error, unexpected error in reagrupe_click(). Report this bug!"));
 		reagrupe_reset();
 		return TEG_STATUS_UNEXPECTED;
 	}
@@ -100,69 +104,58 @@ TEG_STATUS reagrupe_click( PCOUNTRY p )
 	return TEG_STATUS_SUCCESS;
 }
 
-void reagrupe_reset( void )
+void reagrupe_reset(void)
 {
-	if( country_origen != -1 ) {
+	if(country_origen != -1) {
 		g_countries[country_origen].selected &= ~COUNTRY_SELECT_REGROUP;
-		gui_country_select( country_origen );
+		gui_country_select(country_origen);
 		country_origen = -1;
 	}
 
-	if( country_destino != -1 ) {
+	if(country_destino != -1) {
 		g_countries[country_destino].selected &= ~COUNTRY_SELECT_REGROUP;
-		gui_country_select( country_origen );
+		gui_country_select(country_origen);
 		country_destino = -1;
 	}
 }
 
-void reagrupe_bigreset( void )
+void reagrupe_bigreset(void)
 {
 	int i;
 
 	reagrupe_reset();
 
-	for(i=0;i<COUNTRIES_CANT;i++)
+	for(i=0; i<COUNTRIES_CANT; i++) {
 		g_countries[i].ejer_reagrupe = 0;
+	}
 	last_origen = -1;
 	last_destino = -1;
 	last_cant = 0;
 }
 
-TEG_STATUS reagrupe_init( void )
+TEG_STATUS reagrupe_init(void)
 {
 	attack_reset();
 
-	if( reagrupe_check() != TEG_STATUS_SUCCESS ) {
-		textmsg( M_ERR,_("Error, you can't regroup your armies now"));
+	if(reagrupe_check() != TEG_STATUS_SUCCESS) {
+		textmsg(M_ERR, _("Error, you can't regroup your armies now"));
 		return TEG_STATUS_ERROR;
 	}
 	reagrupe_reset();
 	return TEG_STATUS_SUCCESS;
 }
 
-/**
- * @fn TEG_STATUS reagrupe_set_and_save( int src, int dst, int cant )
- * Funcion usada para setear el ejer_reagrupe y si hay algun error
- * en el envio luego restaura
- */
-TEG_STATUS reagrupe_set_and_save( int src, int dst, int cant )
+void reagrupe_set_and_save(int src, int dst, int cant)
 {
 	last_origen = src;
 	last_destino = dst;
 	last_cant = cant;
 	g_countries[ dst ].ejer_reagrupe += cant;
-
-	return TEG_STATUS_SUCCESS;
 }
 
-/**
- * @ TEG_STATUS reagrupe_restore_from_error( void )
- * Si hubo algun error en el envio del reagrupe, esto se encarga
- * de restorear el ejer_reagrupe
- */
-TEG_STATUS reagrupe_restore_from_error( void )
+TEG_STATUS reagrupe_restore_from_error(void)
 {
-	if( last_origen != -1 && last_destino != -1 && last_cant >= 0) {
+	if(last_origen != -1 && last_destino != -1 && last_cant >= 0) {
 		g_countries[ last_destino ].ejer_reagrupe -= last_cant;
 		return TEG_STATUS_SUCCESS;
 	} else {
@@ -171,21 +164,17 @@ TEG_STATUS reagrupe_restore_from_error( void )
 
 }
 
-/**
- * @fn TEG_STATUS reagrupe_out()
- * Envia ejercitos que se estan reagrupando
- */
-TEG_STATUS reagrupe_out( int src, int dst, int cant)
+TEG_STATUS reagrupe_out(int src, int dst, int cant)
 {
 	PLAYER_STATUS e;
 
 	e = ESTADO_GET();
 	if(e==PLAYER_STATUS_REAGRUPE) {
 		reagrupe_reset();
-		reagrupe_set_and_save( src, dst, cant );
-		net_printf(g_game.fd,TOKEN_REAGRUPE"=%d,%d,%d\n",src,dst,cant);
+		reagrupe_set_and_save(src, dst, cant);
+		net_printf(g_game.fd, TOKEN_REAGRUPE"=%d,%d,%d\n", src, dst, cant);
 	} else {
-		textmsg(M_ERR,_("Error, you cant regroup now."));
+		textmsg(M_ERR, _("Error, you cant regroup now."));
 		return TEG_STATUS_ERROR;
 	}
 
@@ -197,22 +186,22 @@ TEG_STATUS reagrupe_out( int src, int dst, int cant)
  * Cuando se esta reagrupando resalta los countries que se pueden reagrupar
  * @param p Pais a resaltar
  */
-TEG_STATUS reagrupe_enter( PCOUNTRY p )
+TEG_STATUS reagrupe_enter(PCOUNTRY p)
 {
-	if( reagrupe_check() != TEG_STATUS_SUCCESS ) {
+	if(reagrupe_check() != TEG_STATUS_SUCCESS) {
 		return TEG_STATUS_UNEXPECTED;
 	}
 
-	if( country_origen == -1 ) {
-		if(p->numjug == WHOAMI() ) {
-			if( p->ejercitos - p->ejer_reagrupe > 1 ) {
+	if(country_origen == -1) {
+		if(p->numjug == WHOAMI()) {
+			if(p->ejercitos - p->ejer_reagrupe > 1) {
 				p->selected |= COUNTRY_SELECT_REGROUP_ENTER;
 				gui_country_select(p->id);
 			}
 		}
-	} else if( country_destino == -1 ) {
-		if(p->numjug == WHOAMI()  ) {
-			if( countries_eslimitrofe( country_origen, p->id ) ) {
+	} else if(country_destino == -1) {
+		if(p->numjug == WHOAMI()) {
+			if(countries_eslimitrofe(country_origen, p->id)) {
 				p->selected |= COUNTRY_SELECT_REGROUP_ENTER;
 				gui_country_select(p->id);
 			}
@@ -221,12 +210,12 @@ TEG_STATUS reagrupe_enter( PCOUNTRY p )
 	return TEG_STATUS_SUCCESS;
 }
 
-TEG_STATUS reagrupe_leave( PCOUNTRY p )
+TEG_STATUS reagrupe_leave(PCOUNTRY p)
 {
-	if( reagrupe_check() != TEG_STATUS_SUCCESS ) {
+	if(reagrupe_check() != TEG_STATUS_SUCCESS) {
 		return TEG_STATUS_UNEXPECTED;
 	}
-	if( p->selected & COUNTRY_SELECT_REGROUP_ENTER ) {
+	if(p->selected & COUNTRY_SELECT_REGROUP_ENTER) {
 		p->selected &= ~COUNTRY_SELECT_REGROUP_ENTER;
 		gui_country_select(p->id);
 	}
