@@ -1,4 +1,3 @@
-/*	$Id: net.h,v 1.5 2001/10/01 03:31:42 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -19,16 +18,21 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef __TEG_NET_H
-#define __TEG_NET_H
+#pragma once
 
 #include <sys/types.h>
 
-ssize_t writen(int fd, const void *vptr, size_t n );
-int net_connect_unix(char *path );
-ssize_t net_readline(int sock, void *gs,size_t maxlen );
-int net_printf(int sock, char *format, ...);
-int net_listen(const char *host, int port );
-int net_connect_tcp( const char *host, int port );
+#ifdef __cplusplus
+extern "C" {
+#endif
 
-#endif /* __TEG_NET_H */
+ssize_t net_readline(int sock, void *gs, size_t maxlen);
+int net_printf(int sock, char *format, ...);
+int net_print(int sock, char *msg);
+int net_listen(const char *host, int port);
+int net_connect_tcp(const char *host, int port);
+int net_close(int s);
+
+#ifdef __cplusplus
+}
+#endif
