@@ -1,4 +1,3 @@
-/*	$Id: stats.h,v 1.2 2001/10/13 17:20:20 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -18,31 +17,31 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
-/**
- * @file stats.h
- * Statistics for the players
- */
-#ifndef __TEG_STATS_H
-#define __TEG_STATS_H
 
-#include "common.h"
+#pragma once
 
-typedef struct _player_stats 
-{
-	int countries_won;	/**< number of countries won */
-	int countries_lost;	/**< number of countries lost */
+#include "cont.h"
 
-	int armies_won;		/**< number of armies killed */
-	int armies_lost;	/**< number of armies lost */
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+typedef struct _player_stats {
+	int countries_won;		/**< number of countries won */
+	int armies_killed;		/**< number of armies killed */
+	int continents_turn[CONT_CANT];	/**< number of turns that the conq was defended */
+	int players_killed;		/**< quantity of players killed */
 
 	int score;		/**< score, based on the stats */
 } PLAYER_STATS, *PPLAYER_STATS;
 
 
-/* prototypes */
 /*! initialize the scores */
-TEG_STATUS stats_init( PPLAYER_STATS s );
-/*! calculate the score */
-TEG_STATUS stats_score( PPLAYER_STATS s );
+void stats_init(PPLAYER_STATS s);
 
-#endif /* __TEG_STATS_H */
+/*! calculate the score */
+void stats_score(PPLAYER_STATS s, CONT const* continents);
+
+#ifdef __cplusplus
+}
+#endif
