@@ -1,4 +1,3 @@
-/*	$Id: xml_support.c,v 1.1 2002/08/31 16:07:03 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2001 Ricardo Quesada
@@ -19,34 +18,40 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include <libxml/xmlmemory.h>
-#include <libxml/parser.h>
+#include "xml_support.h"
 
-#ifndef xmlChildrenNode
-#define xmlChildrenNode childs
-#define xmlRootNode root
-#endif
+#include <assert.h>
 
-xmlNodePtr xml_get_element_children( xmlNodePtr cur )
+xmlNodePtr xml_get_element_children(xmlNodePtr cur)
 {
 	xmlNodePtr ret;
 
 	ret = cur->xmlChildrenNode;
 
-	while( ret && ret->type != XML_ELEMENT_NODE )
+	while(ret && ret->type != XML_ELEMENT_NODE) {
 		ret = ret->next;
+	}
 
 	return ret;
 }
 
-xmlNodePtr xml_get_element_next( xmlNodePtr cur )
+xmlNodePtr xml_get_element_next(xmlNodePtr cur)
 {
 	xmlNodePtr ret;
 
 	ret = cur->next;
 
-	while( ret && ret->type != XML_ELEMENT_NODE )
+	while(ret && ret->type != XML_ELEMENT_NODE) {
 		ret = ret->next;
+	}
 
 	return ret;
 }
+
+void add_numeric_attribute(xmlNodePtr node, char const* name, int number)
+{
+	char buf[22]; // enough for a 64bit integer with sign and zero terminator
+	int res = snprintf(buf, sizeof(buf), "%d", number);
+	assert((res > 0) && (((unsigned)res) < sizeof(buf)));
+	xmlSetProp(node, (xmlChar*)name, (xmlChar*)buf);
+}
