@@ -1,4 +1,3 @@
-/*	$Id: ai.h,v 1.8 2002/08/31 17:45:59 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -18,26 +17,48 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
-/**
- * @file ai.h
- * Inteligecia artificial del robot
- */
 
-#ifndef __TEGR_AI_H
-#define __TEGR_AI_H
+#pragma once
 
-extern int ai_puntaje[COUNTRIES_CANT];
-extern int ai_sorted[COUNTRIES_CANT];
+#ifdef __cplusplus
+extern "C" {
+#endif
 
-TEG_STATUS ai_fichas( int cant );
-TEG_STATUS ai_fichasc( int cant, int conts);
+#include "../common/common.h"
+#include "cont.h"
+
+extern int ai_puntaje[COUNTRIES_CANT*10];
+extern int ai_sorted[COUNTRIES_CANT*10];
+
+/// \brief Initialize / reset the per country attack score
 TEG_STATUS ai_init();
-TEG_STATUS ai_turno();
-TEG_STATUS ai_reagrupe();
-TEG_STATUS ai_tropas( int src, int dst, int cant);
-TEG_STATUS ai_puedocanje( int *p1, int *p2, int *p3 );
-BOOLEAN ai_own_continent( int c );
-TEG_STATUS ai_puntaje_sort(int cant);
-TEG_STATUS ai_puntaje_clean();
 
-#endif /* __TEGR_AI_H */
+/**
+ * \brief Tries to perform one attack.
+ *
+ * \note The next attack will be started by the timeout in gui_main and the
+ *       out_loque() call there.
+ */
+TEG_STATUS ai_turno();
+
+/// Move the armies after the attack turn.
+TEG_STATUS ai_reagrupe();
+
+/// Move armies from my counry to the new conquered country
+TEG_STATUS ai_tropas(int src, int dst, int cant);
+
+/// Try to exchange cards
+TEG_STATUS ai_puedocanje(int *p1, int *p2, int *p3);
+
+/// Do I own the continent number \p c?
+BOOLEAN ai_own_continent(CONTINENTE c);
+
+/// \todo Find out what this function does
+TEG_STATUS ai_puntaje_sort(int cant);
+
+/// Reset the sorting mechanism
+void ai_puntaje_clean();
+
+#ifdef __cplusplus
+}
+#endif
