@@ -1,4 +1,3 @@
-/*	$Id: ai_misc.c,v 1.6 2001/09/03 00:55:40 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -18,40 +17,33 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
-/**
- * @file ai_misc.c
- * Funciones que mucho no tienen que ver con el robot, pero ayudan
- */
 
 #include <stdlib.h>
 #include <stdio.h>
 
 #include "client.h"
 
-/**
- * @fn char *ai_fetch_a_name()
- * Devuelve el nombre de un jugador al azar
- */
 char *ai_fetch_a_name()
 {
 	int i=0;
-	PJUGADOR pJ;
-	PLIST_ENTRY l = g_list_jugador.Flink;
+	PCPLAYER pJ;
+	PLIST_ENTRY l = g_list_player.Flink;
 	int n;
 
-	if( g_juego.jugadores < 2 ) {
+	if(g_game.playeres < 2) {
 		return NULL;
 	}
 
-	n = RANDOM_MAX(0, g_juego.jugadores -1 );
+	n = RANDOM_MAX(0, g_game.playeres -1);
 
-	while( !IsListEmpty( &g_list_jugador ) && (l != &g_list_jugador) ) {
-		if( (i++) == n ) {
-			pJ = (PJUGADOR) l;
-			if( pJ->numjug == WHOAMI() )
+	while(!IsListEmpty(&g_list_player) && (l != &g_list_player)) {
+		if((i++) == n) {
+			pJ = (PCPLAYER) l;
+			if(pJ->numjug == WHOAMI()) {
 				n++;
-			else
-				return pJ->nombre;
+			} else {
+				return pJ->name;
+			}
 		}
 		l = LIST_NEXT(l);
 	}
