@@ -1,4 +1,3 @@
-/*	$Id: ai_msg.c,v 1.25 2002/10/06 03:25:34 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -26,6 +25,8 @@
 #include <stdio.h>
 #include <stdarg.h>
 
+#include "fcintl.h"
+#include "protocol.h"
 #include "client.h"
 #include "ai_msg.h"
 
@@ -146,55 +147,56 @@ static char *names[] = {
 #define NR_NAMES ( sizeof(names) / sizeof(names[0]))
 
 
-TEG_STATUS ai_out_mensaje( int r, char *format, ...)
+TEG_STATUS ai_out_mensaje(int r, char *format, ...)
 {
-        va_list args;
+	va_list args;
 	char buf[PROT_MAX_LEN];
-	int i = RANDOM_MAX(0,r-1);
+	int i = RANDOM_MAX(0, r-1);
 
-	if( i > 3 )
+	if(i > 3) {
 		return TEG_STATUS_ERROR;
+	}
 
 	va_start(args, format);
 	vsnprintf(buf, sizeof(buf) -1, format, args);
 
 	buf[ sizeof(buf) -1 ] = 0;
-	
+
 	va_end(args);
 
-	return out_mensaje( buf );
+	return out_mensaje(buf);
 }
 
-TEG_STATUS ai_msg(int type, char *name )
+TEG_STATUS ai_msg(int type, char const *name)
 {
 	int i;
 	char dst_name[PLAYERNAME_MAX_LEN];
 
-	if( name ) {
-		strncpy( dst_name, name, sizeof(dst_name)-1);
+	if(name) {
+		strncpy(dst_name, name, sizeof(dst_name)-1);
 		dst_name[sizeof(dst_name)-1]=0;
 	} else {
 		i = RANDOM_MAX(0, NR_NAMES-1);
-		strncpy( dst_name, _(names[i]), sizeof(dst_name)-1);
+		strncpy(dst_name, _(names[i]), sizeof(dst_name)-1);
 		dst_name[sizeof(dst_name)-1]=0;
 	}
 
-	switch( type ) {
+	switch(type) {
 	case AI_MSG_MISC:
-		i = RANDOM_MAX(0,NR_MSGS_MISC-1);
-		ai_out_mensaje( 500, _(mensajes_misc[i].msg), dst_name );
+		i = RANDOM_MAX(0, NR_MSGS_MISC-1);
+		ai_out_mensaje(500, _(mensajes_misc[i].msg), dst_name);
 		break;
 	case AI_MSG_HI:
-		i = RANDOM_MAX(0,NR_MSGS_HI-1);
-		ai_out_mensaje( 30, _(mensajes_hi[i].msg), dst_name );
+		i = RANDOM_MAX(0, NR_MSGS_HI-1);
+		ai_out_mensaje(30, _(mensajes_hi[i].msg), dst_name);
 		break;
 	case AI_MSG_BYE:
-		i = RANDOM_MAX(0,NR_MSGS_BYE-1);
-		ai_out_mensaje( 30, _(mensajes_bye[i].msg), dst_name );
+		i = RANDOM_MAX(0, NR_MSGS_BYE-1);
+		ai_out_mensaje(30, _(mensajes_bye[i].msg), dst_name);
 		break;
 	case AI_MSG_ANSWER:
-		i = RANDOM_MAX(0,NR_MSGS_ANSWER-1);
-		ai_out_mensaje( 4, _(mensajes_answer[i].msg), dst_name );
+		i = RANDOM_MAX(0, NR_MSGS_ANSWER-1);
+		ai_out_mensaje(4, _(mensajes_answer[i].msg), dst_name);
 		break;
 	}
 	return TEG_STATUS_SUCCESS;
@@ -202,17 +204,16 @@ TEG_STATUS ai_msg(int type, char *name )
 
 char * ai_name()
 {
-	int i = RANDOM_MAX(0,NR_NAMES-1);
+	int i = RANDOM_MAX(0, NR_NAMES-1);
 	return _(names[i]);
 }
 
-TEG_STATUS ai_findname( char *name )
+TEG_STATUS ai_findname(char const *name)
 {
-	int i;
-
-	for(i=0;i< NR_NAMES;i++) {
-		if( strstr( _(name), _(names[i]) ) != NULL)
+	for(unsigned i=0; i<NR_NAMES; i++) {
+		if(strstr(_(name), _(names[i])) != NULL) {
 			return TEG_STATUS_SUCCESS;
+		}
 	}
 
 	return TEG_STATUS_NOTFOUND;
