@@ -1,4 +1,3 @@
-/*	$Id: ai_msg.h,v 1.5 2001/09/03 00:55:40 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -18,13 +17,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
-/**
- * @file ai_msg.h
- * Mensaje que puede decir el robot ;)
- */
 
-#ifndef __TEGR_AI_MSG_H
-#define __TEGR_AI_MSG_H
+#pragma once
+
+#include "../common/common.h"
+
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 typedef struct _aimsg {
 	char *msg;
@@ -40,8 +40,15 @@ enum {
 	AI_MSG_LAST,
 };
 
-TEG_STATUS ai_msg( int type, char *n );
-char * ai_nombre();
-TEG_STATUS ai_findname( char *name );
+/// Creates a random message, with a random frequency
+TEG_STATUS ai_msg(int type, const char *n);
 
-#endif /* __TEGR_AI_MSG_H */
+/// Choose a random name
+char * ai_name();
+
+/// Checks if the name is a name the robot would use
+TEG_STATUS ai_findname(const char *name);
+
+#ifdef __cplusplus
+}
+#endif
