@@ -1,4 +1,3 @@
-/*	$Id: main.c,v 1.21 2002/08/31 17:46:00 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -26,7 +25,10 @@
 #include <stdio.h>
 #include <string.h>
 
+#include "../common/share.h"
 #include "client.h"
+#include "version.h"
+#include "fcintl.h"
 
 TEG_STATUS main_init()
 {
@@ -36,10 +38,11 @@ TEG_STATUS main_init()
 	return TEG_STATUS_SUCCESS;
 }
 
-int main( int argc, char **argv)
+int main(int argc, char **argv_var)
 {
-	int i,quiet=0;
-	char *option;
+	int i, quiet=0;
+	char const *option;
+	char const **argv = (char const**) argv_var; // save, since we add more constness here
 
 	init_nls();
 	dont_run_as_root();
@@ -53,39 +56,30 @@ int main( int argc, char **argv)
 	g_game.msg_show = M_ERR | M_IMP | M_MSG;
 
 	i = 1;
-	while (i < argc) {
-		if( is_option("--help", argv[i]) ) {
+	while(i < argc) {
+		if(is_option("--help", argv[i])) {
 			fprintf(stderr, _("Usage: %s [option ...]\nValid options are:\n"), argv[0]);
 			fprintf(stderr, _("  -h, --help\t\tPrint a summary of the options\n"));
 			fprintf(stderr, _("  -n, --name NAME\tUse NAME as name\n"));
 			fprintf(stderr, _("  -p, --port PORT\tConnect to server port PORT\n"));
 			fprintf(stderr, _("  -s, --server HOST\tConnect to the server at HOST\n"));
 			fprintf(stderr, _("  -v, --version\t\tPrint the version number\n"));
-#ifdef WITH_GGZ
-			fprintf(stderr, _("  -g, --ggz\t\tEnable GGZ mode\n"));
-#endif
 			fprintf(stderr, _("  -c, --connected\t\tThe robot is already connected\n"));
 			fprintf(stderr, _("  -q, --quiet\t\tdont show messages\n"));
 			exit(0);
-		} else if (is_option("--version",argv[i])) {
+		} else if(is_option("--version", argv[i])) {
 			fprintf(stderr, TEG_NAME" v"VERSION"\n");
 			exit(0);
-		} else if ((option = get_option("--name",argv,&i,argc)) != NULL) {
-			strncpy( g_game.myname, option, PLAYERNAME_MAX_LEN );
-		} else if ((option = get_option("--port",argv,&i,argc)) != NULL) {
+		} else if((option = get_option("--name", argv, &i, argc)) != NULL) {
+			strncpy(g_game.myname, option, PLAYERNAME_MAX_LEN);
+		} else if((option = get_option("--port", argv, &i, argc)) != NULL) {
 			g_game.serport=atoi(option);
-		} else if ((option = get_option("--server",argv,&i,argc)) != NULL) {
-			strncpy( g_game.sername, option, SERVER_NAMELEN );
-#ifdef WITH_GGZ
-		} else if ( is_option("--ggz",argv[i])) {
-			g_game.with_ggz = 1;
+		} else if((option = get_option("--server", argv, &i, argc)) != NULL) {
+			strncpy(g_game.sername, option, SERVER_NAMELEN);
+		} else if(is_option("--connected", argv[i])) {
 			g_game.already_connected = 1;
 			quiet = 1;
-#endif
-		} else if ( is_option("--connected",argv[i])) {
-			g_game.already_connected = 1;
-			quiet = 1;
-		} else if ( is_option("--quiet",argv[i])) {
+		} else if(is_option("--quiet", argv[i])) {
 			quiet = 1;
 		} else {
 			fprintf(stderr, _("Unrecognized option: \"%s\"\n"), argv[i]);
@@ -94,12 +88,14 @@ int main( int argc, char **argv)
 		i++;
 	}
 
-	if(quiet) g_game.msg_show = M_MSG;
+	if(quiet) {
+		g_game.msg_show = M_MSG;
+	}
 
-	textmsg(M_IMP,_("Tenes Empanadas Graciela - Robot v%s - by Ricardo Quesada\n"),VERSION);
-	textmsg(M_IMP,_("Robot intelligence: %d%%"),62);
+	textmsg(M_IMP, _("Tenes Empanadas Graciela - Robot v%s - by Ricardo Quesada\n"), VERSION);
+	textmsg(M_IMP, _("Robot intelligence: %d%%"), 62);
 
-	gui_init(argc, argv);
+	gui_init(argc, argv_var);
 
 	gui_main();
 
