@@ -1,4 +1,3 @@
-/*	$Id: globals.h,v 1.30 2002/09/10 12:17:41 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -19,8 +18,14 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef __TEGS_GLOBALS_H
-#define __TEGS_GLOBALS_H
+#pragma once
+
+#include "../common/common.h"
+#include "player.h"
+
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 typedef struct _sgame {
 	int connections;	/**< quantity of connections */
@@ -67,7 +72,6 @@ typedef struct _server {
 	int port;		/* port to listen to (default: 2000) */
 	int max_players;	/* max players ( default: 6 ) */
 	int max_connections;	/* max connections ( default: 15 ) */
-	BOOLEAN with_ggz;	/* GGZ mode */
 
 	char metaserver_name[SERVER_NAMELEN];	/* metaserver name */
 	int metaserver_port;	/* port of metaserver */
@@ -75,6 +79,8 @@ typedef struct _server {
 	BOOLEAN kick_unparent_robots;	/* kick robots when there are no humans */
 } SERVER, *PSERVER;
 extern SERVER g_server;
-	
 
-#endif /* __TEGS_GLOBALS_H */
+
+#ifdef __cplusplus
+}
+#endif
