@@ -1,4 +1,3 @@
-/*	$Id: main.h,v 1.7 2001/12/21 04:27:44 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -18,12 +17,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
-/**
- * @file main.h
- */
 
-#ifndef __TEGS_MAIN_H
-#define __TEGS_MAIN_H
+#pragma once
+
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 /**! initialize the game */
 void game_init();
@@ -35,9 +34,16 @@ void game_new();
 void game_end();
 
 /**! when the game is over */
-BOOLEAN game_is_finished( void );
+BOOLEAN game_is_finished(void);
 
 void server_init();
-void fd_remove( int fd );
 
-#endif /* __TEGS_MAIN_H */
+/**! removes and closes an fd from the list of fd */
+void fd_remove(int fd);
+
+/**! adds a new fd to the list of fd */
+void fd_add(int fd);
+
+#ifdef __cplusplus
+}
+#endif
