@@ -1,4 +1,3 @@
-/*	$Id: sernet.c,v 1.7 2001/12/16 01:29:46 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -25,15 +24,16 @@
 #include <stdio.h>
 #include <stdarg.h>
 
-#include "server.h"
+#include "../common/net.h"
+#include "../common/protocol.h"
+#include "player.h"
 
-int
-netall_printf( char *format, ...)
+void netall_printf(char *format, ...)
 {
-        va_list args;
+	va_list args;
 	char buf[PROT_MAX_LEN];
-	PLIST_ENTRY l = g_list_jugador.Flink;
-	PJUGADOR j;
+	PLIST_ENTRY l = g_list_player.Flink;
+	PSPLAYER j;
 
 	va_start(args, format);
 	vsnprintf(buf, sizeof(buf) -1, format, args);
@@ -41,13 +41,12 @@ netall_printf( char *format, ...)
 
 	buf[ sizeof(buf) -1 ] = 0;
 
-	while( !IsListEmpty( &g_list_jugador ) && (l != &g_list_jugador) ) {
-		j = (PJUGADOR) l;
+	while(!IsListEmpty(&g_list_player) && (l != &g_list_player)) {
+		j = (PSPLAYER) l;
 		if(j->fd>0) {
-			net_printf(j->fd, buf);
+			net_print(j->fd, buf);
 		}
 
-		l = LIST_NEXT( l );
+		l = LIST_NEXT(l);
 	}
-	return 0;
 }
