@@ -1,4 +1,3 @@
-/*	$Id: server.h,v 1.17 2002/10/14 01:25:04 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -26,22 +25,18 @@
 #ifndef __TEGS_SERVER_H
 #define __TEGS_SERVER_H
 
-#include "all.h"
-
-#include "tarjeta.h"
+#include "../common/tarjeta.h"
 #include "countries.h"
 #include "player.h"
 #include "turno.h"
 #include "globals.h"
 #include "sernet.h"
-#include "protocol.h"
+#include "../common/protocol.h"
 #include "play.h"
 #include "console.h"
 #include "helper.h"
 #include "main.h"
-#include "missions.h"
-#include "ggz_server.h"
+#include "../common/missions.h"
 #include "options.h"
-#include "metaserver.h"
 
 #endif /* __TEGS_SERVER_H */
